@@ -18,16 +18,13 @@ from bamboo_engine.config import Settings
 from bamboo_engine.template import Template
 from bamboo_engine.eri import ProcessInfo, ContextValue, ContextValueType, NodeType
 from bamboo_engine.handler import register_handler, NodeHandler, ExecuteResult
-from bamboo_engine.utils.string import format_var_key
 
 logger = logging.getLogger("bamboo_engine")
 
 
 @register_handler(NodeType.SubProcess)
 class SubProcessHandler(NodeHandler):
-    def execute(
-        self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str
-    ) -> ExecuteResult:
+    def execute(self, process_info: ProcessInfo, loop: int, inner_loop: int, version: str) -> ExecuteResult:
         """
         节点的 execute 处理逻辑
 
@@ -64,9 +61,7 @@ class SubProcessHandler(NodeHandler):
             inputs_refs,
         )
 
-        additional_refs = self.runtime.get_context_key_references(
-            pipeline_id=top_pipeline_id, keys=inputs_refs
-        )
+        additional_refs = self.runtime.get_context_key_references(pipeline_id=top_pipeline_id, keys=inputs_refs)
         inputs_refs = inputs_refs.union(additional_refs)
         logger.info(
             "[%s] %s subprocess final refs: %s",
@@ -76,9 +71,7 @@ class SubProcessHandler(NodeHandler):
         )
 
         # prepare context
-        context_values = self.runtime.get_context_values(
-            pipeline_id=top_pipeline_id, keys=inputs_refs
-        )
+        context_values = self.runtime.get_context_values(pipeline_id=top_pipeline_id, keys=inputs_refs)
 
         # pre extract loop outputs
         loop_value = loop + Settings.RERUN_INDEX_OFFSET
@@ -99,7 +92,8 @@ class SubProcessHandler(NodeHandler):
         )
 
         context = Context(self.runtime, context_values, root_pipeline_inputs)
-        hydrated_context = context.hydrate(deformat=True)
+        # TODO mute error temporarily, remove this logic when subprocess retry feature finished
+        hydrated_context = context.hydrate(deformat=True, mute_error=True)
         logger.info(
             "[%s] %s subprocess parent hydrated context: %s",
             root_pipeline_id,
@@ -124,9 +118,7 @@ class SubProcessHandler(NodeHandler):
         # update subprocess context, inject subprocess data
         self.runtime.upsert_plain_context_values(self.node.id, sub_context_values)
         process_info.pipeline_stack.append(self.node.id)
-        self.runtime.set_pipeline_stack(
-            process_info.process_id, process_info.pipeline_stack
-        )
+        self.runtime.set_pipeline_stack(process_info.process_id, process_info.pipeline_stack)
 
         return ExecuteResult(
             should_sleep=False,
